import rsnet_py as rsp
from jinja2 import Template
import abc

class Mapper(abc.ABC):
    @abc.abstractclassmethod
    def setNamespaceTag(self, namespace: str, tag: str) -> None:
        ...
    
    @abc.abstractclassmethod
    def get(self, name: str, values = None) -> str:
        ...

class Jinja2Mapper(Mapper):
    def __init__(self, conf_paths: list, namespace: str = None, tag: str = None):
        self._conf_paths = conf_paths
        self._mapper = {}
        if (namespace is not None) and (tag is not None):
            self.setNamespaceTag(namespace, tag)
            
    def setNamespaceTag(self, namespace: str, tag: str) -> None:
        template = rsp.mapper.YAMLConfig(self._conf_paths)
        template.setCurrent(namespace, tag)
        
        self._mapper = {}
        for config in template.getCurrent()["configs"]:
            for mapper in config["config"]["mapper"]:
                self._mapper[mapper["name"]] = mapper["temp"]
    
    def get(self, key: str, values=None) -> str:
        return Template(self._mapper[key]).render(values=values)